@@ -1,6 +1,6 @@
 /*
     This file is part of libmicrohttpd
-     (C) 2007-2013 Daniel Pittman and Christian Grothoff
+     Copyright (C) 2007-2015 Daniel Pittman and Christian Grothoff
 
      This library is free software; you can redistribute it and/or
      modify it under the terms of the GNU Lesser General Public
@@ -741,7 +741,9 @@ build_header_response (struct MHD_Connection *connection)
              close the connection */
           /* 'close' header doesn't exist yet, see if we need to add one;
              if the client asked for a close, no need to start chunk'ing */
-          if (MHD_YES == keepalive_possible (connection))
+          if ( (MHD_YES == keepalive_possible (connection)) &&
+               (MHD_str_equal_caseless_ (MHD_HTTP_VERSION_1_1,
+                                         connection->version) ) )
             {
               have_encoding = MHD_get_response_header (connection->response,
                                                        MHD_HTTP_HEADER_TRANSFER_ENCODING);
@@ -762,7 +764,8 @@ build_header_response (struct MHD_Connection *connection)
             }
           else
             {
-              /* Keep alive not possible => set close header if not present */
+              /* Keep alive or chunking not possible
+                 => set close header if not present */
               if (NULL == response_has_close)
                 must_add_close = MHD_YES;
             }
@@ -782,8 +785,8 @@ build_header_response (struct MHD_Connection *connection)
       if ( (MHD_SIZE_UNKNOWN != connection->response->total_size) &&
            (NULL == have_content_length) &&
            ( (NULL == connection->method) ||
-             (!MHD_str_equal_caseless_ (connection->method,
-                               MHD_HTTP_METHOD_CONNECT)) ) )
+             (! MHD_str_equal_caseless_ (connection->method,
+                                         MHD_HTTP_METHOD_CONNECT)) ) )
         {
           /*
             Here we add a content-length if one is missing; however,
@@ -2590,7 +2593,7 @@ MHD_connection_handle_idle (struct MHD_Connection *connection)
           end =
             MHD_get_response_header (connection->response,
 				     MHD_HTTP_HEADER_CONNECTION);
-          client_close = ((NULL != end) && (0 == strcasecmp (end, "close")));
+          client_close = ((NULL != end) && (MHD_str_equal_caseless_(end, "close")));
           MHD_destroy_response (connection->response);
           connection->response = NULL;
           if ( (NULL != daemon->notify_completed) &&
@@ -2859,29 +2862,31 @@ MHD_set_connection_option (struct MHD_Connection *connection,
       if ( (0 != (daemon->options & MHD_USE_THREAD_PER_CONNECTION)) &&
 	   (MHD_YES != MHD_mutex_lock_ (&daemon->cleanup_connection_mutex)) )
 	MHD_PANIC ("Failed to acquire cleanup mutex\n");
-      if (MHD_YES != connection->suspended) {
-        if (connection->connection_timeout == daemon->connection_timeout)
-          XDLL_remove (daemon->normal_timeout_head,
-                       daemon->normal_timeout_tail,
-                       connection);
-        else
-          XDLL_remove (daemon->manual_timeout_head,
-                       daemon->manual_timeout_tail,
-                       connection);
-      }
+      if (MHD_YES != connection->suspended)
+        {
+          if (connection->connection_timeout == daemon->connection_timeout)
+            XDLL_remove (daemon->normal_timeout_head,
+                         daemon->normal_timeout_tail,
+                         connection);
+          else
+            XDLL_remove (daemon->manual_timeout_head,
+                         daemon->manual_timeout_tail,
+                         connection);
+        }
       va_start (ap, option);
       connection->connection_timeout = va_arg (ap, unsigned int);
       va_end (ap);
-      if (MHD_YES != connection->suspended) {
-        if (connection->connection_timeout == daemon->connection_timeout)
-          XDLL_insert (daemon->normal_timeout_head,
-                       daemon->normal_timeout_tail,
-                       connection);
-        else
-          XDLL_insert (daemon->manual_timeout_head,
-                       daemon->manual_timeout_tail,
-                       connection);
-      }
+      if (MHD_YES != connection->suspended)
+        {
+          if (connection->connection_timeout == daemon->connection_timeout)
+            XDLL_insert (daemon->normal_timeout_head,
+                         daemon->normal_timeout_tail,
+                         connection);
+          else
+            XDLL_insert (daemon->manual_timeout_head,
+                         daemon->manual_timeout_tail,
+                         connection);
+        }
       if ( (0 != (daemon->options & MHD_USE_THREAD_PER_CONNECTION)) &&
 	   (MHD_YES != MHD_mutex_unlock_ (&daemon->cleanup_connection_mutex)) )
 	MHD_PANIC ("Failed to release cleanup mutex\n");
